==> groupoffice-com-4.0.97.tar.gz: groupoffice-com-4.0.97/modules/calendar/language/fr.js <==
/////////////////////////////////////////////////////////////////////////////////
//
// Copyright Intermesh
// 
// This file is part of Group-Office. You should have received a copy of the
// Group-Office license along with Group-Office. See the file /LICENSE.TXT
// 
// If you have questions write an e-mail to info@intermesh.nl
//
// @copyright Copyright Intermesh
// @version $Id: fr.js 8287 2011-10-12 12:03:09Z mschering $
// @author Merijn Schering <mschering@intermesh.nl>
//
// French Translation
// Version : 3.7.29 
// Author : Lionel JULLIEN
// Date : September, 27 2011
//
/////////////////////////////////////////////////////////////////////////////////

GO.calendar.lang.addressbook='Carnet d\'adresses';
GO.calendar.lang.appointment = 'Rendez-vous';
GO.calendar.lang.appointments = 'Rendez-vous';
GO.calendar.lang.recurrence = 'Récurrence';
GO.calendar.lang.options = 'Options';
GO.calendar.lang.repeatForever = 'Répéter pour toujours';
GO.calendar.lang.repeatEvery = 'Répéter chaque';
GO.calendar.lang.repeatUntil = 'Répéter jusqu\'au';
GO.calendar.lang.busy = 'Me montrer comme occupé';
GO.calendar.lang.allDay = 'Evènement sur la journée';
GO.calendar.lang.navigation = 'Navigation';
GO.calendar.lang.oneDay = '1 Jour';
GO.calendar.lang.fiveDays = '5 Jours';
GO.calendar.lang.sevenDays = '7 Jours';
GO.calendar.lang.month = 'Mois';
GO.calendar.lang.recurringEvent = 'Evènement récurrent';
GO.calendar.lang.deleteRecurringEvent = 'Voulez-vous supprimer une seule occurrence ou toutes les occurrences de cet évènement récurrent??';
GO.calendar.lang.singleOccurence = 'Occurrence simple';
GO.calendar.lang.entireSeries = 'Toute la série';
GO.calendar.lang.calendar = 'Calendrier';
GO.calendar.lang.calendars = 'Calendriers';
GO.calendar.lang.views = 'Vues';
GO.calendar.lang.administration = 'Administration';
GO.calendar.lang.needsAction = 'Action nécessaire';
GO.calendar.lang.accepted = 'Accepté';
GO.calendar.lang.declined = 'Décliné';
GO.calendar.lang.tentative = 'Tentative';
GO.calendar.lang.delegated = 'Délégué';
GO.calendar.lang.noRecurrence = 'Pas de récurrence';
GO.calendar.lang.notRespondedYet = 'Aucune réponse pour le moment';
GO.calendar.lang.days = 'jours';
GO.calendar.lang.weeks = 'semaines';
GO.calendar.lang.monthsByDate = 'mois par date';
GO.calendar.lang.monthsByDay = 'mois par jour';
GO.calendar.lang.years = 'années';
GO.calendar.lang.atDays = 'Aux jours';
GO.calendar.lang.noReminder = 'Aucun rappel';
GO.calendar.lang.reminder='Rappel';
GO.calendar.lang.participants = 'Participants';
GO.calendar.lang.checkAvailability = 'Vérifier la disponibilité';
GO.calendar.lang.sendInvitation = 'Envoyer une invitation';
GO.calendar.lang.emailSendingNotConfigured = 'L\'envoi par e-mail n\'est pas configuré.';
GO.calendar.lang.privateEvent = 'Privé';
GO.calendar.lang.noInformationAvailable = 'Aucune information disponible';
GO.calendar.lang.noParticipantsToDisplay = 'Aucun participant à afficher';
GO.calendar.lang.previousDay = 'Jour précedent';
GO.calendar.lang.nextDay = 'Jour suivant';
GO.calendar.lang.noAppointmentsToDisplay = 'Aucun rendez-vous à afficher';
GO.calendar.lang.selectCalendar = 'Sélectionnez un calendrier';
GO.calendar.lang.selectCalendarForAppointment = 'Sélectionnez le calendrier dans lequel ajouter le rendez-vous';
GO.calendar.lang.closeWindow = 'Le rendez-vous a été accepté et programmé. Vous pouvez fermer cette fenêtre.';
GO.calendar.lang.list='Liste';
GO.calendar.lang.editRecurringEvent='Voulez-vous éditer cette occurrence ou la série complète ?';
GO.calendar.lang.selectIcalendarFile='Sélectionner un fichier icalendar (*.ics)';
GO.calendar.lang.location='Lieu';
GO.calendar.lang.startsAt='Débute à';
GO.calendar.lang.endsAt='Se termine à';
GO.calendar.lang.eventDefaults='Paramètres par défaut pour les rendez-vous';
GO.calendar.lang.importToCalendar='Ajouter directement ce rendez-vous';
GO.calendar.lang.default_calendar='Calendrier par défaut';
GO.calendar.lang.status='Statut';
GO.calendar.lang.resource_groups='Groupes de ressources';
GO.calendar.lang.resource_group='Groupe de ressources';
GO.calendar.lang.resources='Ressources';
GO.calendar.lang.resource='Ressource';
GO.calendar.lang.calendar_group='Groupe de calendriers';
GO.calendar.lang.admins='Administrateurs';
GO.calendar.lang.no_group_selected='Il y a des erreurs dans le formulaire. Vous devez selectionner un groupe pour cette ressource.';
GO.calendar.lang.visibleCalendars='Calendriers visibles';
GO.calendar.lang.visible='Visible';
GO.calendar.lang.group='Groupe';
GO.calendar.lang.no_status='Nouveau';
GO.calendar.lang.no_custom_fields='Il n\'y a aucune option supplémentaire disponible.';
GO.calendar.lang.show_bdays='Afficher les anniversaires';
GO.calendar.lang.show_tasks='Afficher les tâches';
GO.calendar.lang.myCalendar='Mon calendrier';
GO.calendar.lang.merge='Fusionner';
GO.calendar.lang.ownColor = 'Donner une couleur unique à chaque calendrier';
GO.calendar.lang.ignoreConflictsTitle = 'Ignorer le conflit ?';
GO.calendar.lang.ignoreConflictsMsg = 'Cet événement est en conflit avec un autre présent dans votre calendrier. Forcer l\'enregistrement ?';
GO.calendar.lang.resourceConflictTitle = 'Conflit de ressource';
GO.calendar.lang.resourceConflictMsg = 'Une ou plusieures ressources de cet événement sont déjà utilisées pendant la même période :</br>';
GO.calendar.lang.view = 'Vue';

GO.calendar.lang.calendarsPermissions='Droits des calendriers';
GO.calendar.lang.resourcesPermissions='Droits des ressources';
GO.calendar.lang.daynames[0]='Dimanche';
GO.calendar.lang.daynames[1]='Lundi';
GO.calendar.lang.daynames[2]='Mardi';
GO.calendar.lang.daynames[3]='Mercredi';
GO.calendar.lang.daynames[4]='Jeudi';
GO.calendar.lang.daynames[5]='Vendredi';
GO.calendar.lang.daynames[6]='Samedi';
GO.calendar.lang.categories='Catégories';
GO.calendar.lang.category='Catégorie';
GO.calendar.lang.globalCategory='Catégorie globale';
GO.calendar.lang.selectCategory='Sélectionnez la catégorie';
GO.calendar.lang.duration='Laps de temps';
GO.calendar.lang.move='Déplacer';
GO.calendar.lang.showInfo='Détails';
GO.calendar.lang.copyEvent='Copier le rendez-vous';
GO.calendar.lang.moveEvent='Déplacer le rendez-vous';
GO.calendar.lang.eventInfo='Détails du rendez-vous';
GO.calendar.lang.isOrganizer='Organisateur';
GO.calendar.lang.sendInvitationInitial='Voulez vous envoyer une invitation aux participants ?';
GO.calendar.lang.sendInvitationUpdate='Voulez vous envoyer les informations à jour du rendez-vous aux participants ?';
GO.calendar.lang.sendCancellation='Voulez vous envoyer aux participants une confirmation de l\'annulation ?';
GO.calendar.lang.forthcomingAppointments='Rendez-vous à venir';
GO.calendar.lang.quarterShort= 'Trimestre ';
GO.calendar.lang.globalsettings_templatelabel = 'Modèle';
GO.calendar.lang.globalsettings_allchangelabel = 'Renommer tous les existants';
GO.calendar.lang.globalsettings_renameall = 'Etes-vous sûr de vouloir renommer tous les calendriers par défaut des utilisateurs ?';
GO.calendar.lang.publishICS='Publier un fichier iCalendar des événements du mois en cours et des mois futurs. Attention ! Le calendrier sera consultable par tout le monde.';
GO.calendar.lang.addTimeRegistration='Importer dans la gestion du temps';
GO.calendar.lang.showNotBusy='Ne pas montrer les nouvelles réservation comme occupée';
GO.calendar.lang.sendEmailParticipants = 'Créer un email pour les participants';

==> groupoffice-com-4.0.144.tar.gz: groupoffice-com-4.0.144/modules/calendar/language/fr.js <==
/////////////////////////////////////////////////////////////////////////////////
//
// Copyright Intermesh
// 
// This file is part of Group-Office. You should have received a copy of the
// Group-Office license along with Group-Office. See the file /LICENSE.TXT
// 
// If you have questions write an e-mail to info@intermesh.nl
//
// @copyright Copyright Intermesh
// @version $Id: fr.js 12014 2012-09-20 16:01:48Z mschering $
// @author Merijn Schering <mschering@intermesh.nl>
//
// French Translation
// Version : 4.0.99
// Author : Lionel JULLIEN / Boris HERBINIERE-SEVE
// Date : September, 20 2012
//
/////////////////////////////////////////////////////////////////////////////////

GO.calendar.lang.addressbook='Carnet d\'adresses';
GO.calendar.lang.appointment = 'Rendez-vous';
GO.calendar.lang.appointments = 'Rendez-vous';
GO.calendar.lang.recurrence = 'Récurrence';
GO.calendar.lang.options = 'Options';
GO.calendar.lang.repeatForever = 'Répéter pour toujours';
GO.calendar.lang.repeatEvery = 'Répéter chaque';
GO.calendar.lang.repeatUntil = 'Répéter jusqu\'au';
GO.calendar.lang.busy = 'Me montrer comme occupé';
GO.calendar.lang.allDay = 'Evènement sur la journée';
GO.calendar.lang.navigation = 'Navigation';
GO.calendar.lang.oneDay = '1 Jour';
GO.calendar.lang.fiveDays = '5 Jours';
GO.calendar.lang.sevenDays = '7 Jours';
GO.calendar.lang.month = 'Mois';
GO.calendar.lang.recurringEvent = 'Evènement récurrent';
GO.calendar.lang.deleteRecurringEvent = 'Voulez-vous supprimer une seule occurrence ou toutes les occurrences de cet évènement récurrent??';
GO.calendar.lang.singleOccurence = 'Occurrence simple';
GO.calendar.lang.entireSeries = 'Toute la série';
GO.calendar.lang.calendar = 'Calendrier';
GO.calendar.lang.calendars = 'Calendriers';
GO.calendar.lang.views = 'Vues';
GO.calendar.lang.administration = 'Administration';
GO.calendar.lang.needsAction = 'Action nécessaire';
GO.calendar.lang.accepted = 'Accepté';
GO.calendar.lang.declined = 'Décliné';
GO.calendar.lang.tentative = 'Tentative';
GO.calendar.lang.delegated = 'Délégué';
GO.calendar.lang.noRecurrence = 'Pas de récurrence';
GO.calendar.lang.notRespondedYet = 'Aucune réponse pour le moment';
GO.calendar.lang.days = 'jours';
GO.calendar.lang.weeks = 'semaines';
GO.calendar.lang.monthsByDate = 'mois par date';
GO.calendar.lang.monthsByDay = 'mois par jour';
GO.calendar.lang.years = 'années';
GO.calendar.lang.atDays = 'Aux jours';
GO.calendar.lang.noReminder = 'Aucun rappel';
GO.calendar.lang.reminder='Rappel';
GO.calendar.lang.participants = 'Participants';
GO.calendar.lang.checkAvailability = 'Vérifier la disponibilité';
GO.calendar.lang.sendInvitation = 'Envoyer une invitation';
GO.calendar.lang.emailSendingNotConfigured = 'L\'envoi par e-mail n\'est pas configuré.';
GO.calendar.lang.privateEvent = 'Privé';
GO.calendar.lang.noInformationAvailable = 'Aucune information disponible';
GO.calendar.lang.noParticipantsToDisplay = 'Aucun participant à afficher';
GO.calendar.lang.previousDay = 'Jour précedent';
GO.calendar.lang.nextDay = 'Jour suivant';
GO.calendar.lang.noAppointmentsToDisplay = 'Aucun rendez-vous à afficher';
GO.calendar.lang.selectCalendar = 'Sélectionnez un calendrier';
GO.calendar.lang.selectCalendarForAppointment = 'Sélectionnez le calendrier dans lequel ajouter le rendez-vous';
GO.calendar.lang.closeWindow = 'Le rendez-vous a été accepté et programmé. Vous pouvez fermer cette fenêtre.';
GO.calendar.lang.list='Liste';
GO.calendar.lang.editRecurringEvent='Voulez-vous éditer cette occurrence ou la série complète ?';
GO.calendar.lang.selectIcalendarFile='Sélectionner un fichier icalendar (*.ics)';
GO.calendar.lang.location='Lieu';
GO.calendar.lang.startsAt='Débute à';
GO.calendar.lang.endsAt='Se termine à';
GO.calendar.lang.eventDefaults='Paramètres par défaut pour les rendez-vous';
GO.calendar.lang.importToCalendar='Ajouter directement ce rendez-vous';
GO.calendar.lang.default_calendar='Calendrier par défaut';
GO.calendar.lang.status='Statut';
GO.calendar.lang.resource_groups='Groupes de ressources';
GO.calendar.lang.resource_group='Groupe de ressources';
GO.calendar.lang.resources='Ressources';
GO.calendar.lang.resource='Ressource';
GO.calendar.lang.calendar_group='Groupe de calendriers';
GO.calendar.lang.admins='Administrateurs';
GO.calendar.lang.no_group_selected='Il y a des erreurs dans le formulaire. Vous devez selectionner un groupe pour cette ressource.';
GO.calendar.lang.visibleCalendars='Calendriers visibles';
GO.calendar.lang.visible='Visible';
GO.calendar.lang.group='Groupe';
GO.calendar.lang.no_status='Nouveau';
GO.calendar.lang.no_custom_fields='Il n\'y a aucune option supplémentaire disponible.';
GO.calendar.lang.show_bdays='Afficher les anniversaires';
GO.calendar.lang.show_tasks='Afficher les tâches';
GO.calendar.lang.myCalendar='Mon calendrier';
GO.calendar.lang.merge='Fusionner';
GO.calendar.lang.ownColor = 'Donner une couleur unique à chaque calendrier';
GO.calendar.lang.ignoreConflictsTitle = 'Ignorer le conflit ?';
GO.calendar.lang.ignoreConflictsMsg = 'Cet événement est en conflit avec un autre présent dans votre calendrier. Forcer l\'enregistrement ?';
GO.calendar.lang.resourceConflictTitle = 'Conflit de ressource';
GO.calendar.lang.resourceConflictMsg = 'Une ou plusieures ressources de cet événement sont déjà utilisées pendant la même période :</br>';
GO.calendar.lang.view = 'Vue';

GO.calendar.lang.calendarsPermissions='Droits des calendriers';
GO.calendar.lang.resourcesPermissions='Droits des ressources';
GO.calendar.lang.daynames[0]='Dimanche';
GO.calendar.lang.daynames[1]='Lundi';
GO.calendar.lang.daynames[2]='Mardi';
GO.calendar.lang.daynames[3]='Mercredi';
GO.calendar.lang.daynames[4]='Jeudi';
GO.calendar.lang.daynames[5]='Vendredi';
GO.calendar.lang.daynames[6]='Samedi';
GO.calendar.lang.categories='Catégories';
GO.calendar.lang.category='Catégorie';
GO.calendar.lang.globalCategory='Catégorie globale';
GO.calendar.lang.selectCategory='Sélectionnez la catégorie';
GO.calendar.lang.duration='Laps de temps';
GO.calendar.lang.move='Déplacer';
GO.calendar.lang.showInfo='Détails';
GO.calendar.lang.copyEvent='Copier le rendez-vous';
GO.calendar.lang.moveEvent='Déplacer le rendez-vous';
GO.calendar.lang.eventInfo='Détails du rendez-vous';
GO.calendar.lang.isOrganizer='Organisateur';
GO.calendar.lang.sendInvitationInitial='Voulez vous envoyer une invitation aux participants ?';
GO.calendar.lang.sendInvitationUpdate='Voulez vous envoyer les informations à jour du rendez-vous aux participants ?';
GO.calendar.lang.sendCancellation='Voulez vous envoyer aux participants une confirmation de l\'annulation ?';
GO.calendar.lang.forthcomingAppointments='Rendez-vous à venir';
GO.calendar.lang.quarterShort= 'Trimestre ';
GO.calendar.lang.globalsettings_templatelabel = 'Modèle';
GO.calendar.lang.globalsettings_allchangelabel = 'Renommer tous les existants';
GO.calendar.lang.globalsettings_renameall = 'Etes-vous sûr de vouloir renommer tous les calendriers par défaut des utilisateurs ?';
GO.calendar.lang.publishICS='Publier un fichier iCalendar des événements du mois en cours et des mois futurs. Attention ! Le calendrier sera consultable par tout le monde.';
GO.calendar.lang.addTimeRegistration='Importer dans la gestion du temps';
GO.calendar.lang.showNotBusy='Ne pas montrer les nouvelles réservations comme occupées';
GO.calendar.lang.sendEmailParticipants = 'Créer un email pour les participants';
GO.calendar.lang.calendarColor= 'Couleur du Calendrier';
GO.calendar.lang.colors= 'Couleurs';
GO.calendar.lang.setColors= 'Définir les couleurs pour chaque calendrier';
